WheelTimerPicker class

Inheritance

Constructors

WheelTimerPicker({Key? key, int initialHour = 1, int initialMinute = 0, String initialPeriod = 'AM', double itemHeight = 50.0, TextStyle? selectedTextStyle, TextStyle? unselectedTextStyle, Color dividerColor = Colors.grey, void onTimeChanged(TimeOfDay)?, double? leftPadding, double? rightPadding})
const

Properties

dividerColor Color
final
hashCode int
The hash code for this object.
no setterinherited
initialHour int
final
initialMinute int
final
initialPeriod String
final
itemHeight double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftPadding double?
final
onTimeChanged → void Function(TimeOfDay)?
final
rightPadding double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedTextStyle TextStyle?
final
unselectedTextStyle TextStyle?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<WheelTimerPicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited